@@ -1,12 +1,14 @@
 package Sub::Exporter::Progressive;
-
+$Sub::Exporter::Progressive::VERSION = '0.001012';
 use strict;
 use warnings;
 
-our $VERSION = '0.001008';
+# ABSTRACT: Only use Sub::Exporter if you need it
 
-use Carp 'croak';
-use List::Util 'first';
+sub _croak {
+  require Carp;
+  &Carp::croak;
+}
 
 sub import {
    my ($self, @args) = @_;
@@ -23,12 +25,18 @@ sub import {
       use strict;
       my ($self, @args) = @_;
 
-      if (first { ref || !m/ \A [:-]? \w+ \z /xm } @args) {
-         croak 'your usage of Sub::Exporter::Progressive requires Sub::Exporter to be installed'
+      if ( grep {
+         length ref $_
+            or
+         $_ !~ / \A [:-]? \w+ \z /xm
+      } @args ) {
+         _croak 'your usage of Sub::Exporter::Progressive requires Sub::Exporter to be installed'
             unless eval { require Sub::Exporter };
          $full_exporter ||= Sub::Exporter::build_exporter($export_data->{original});
 
          goto $full_exporter;
+      } elsif ( defined( (my ($num) = grep { m/^\d/ } @args)[0] ) ) {
+         _croak "cannot export symbols with a leading digit: '$num'";
       } else {
          require Exporter;
          s/ \A - /:/xm for @args;
@@ -52,32 +60,36 @@ sub sub_export_options {
    my @defaults;
    my %tags;
 
-   if ($setup eq '-setup') {
+   if ( ($setup||'') eq '-setup') {
       my %options = %$options;
 
       OPTIONS:
       for my $opt (keys %options) {
          if ($opt eq 'exports') {
 
-            croak $too_complicated if ref $options{exports} ne 'ARRAY';
+            _croak $too_complicated if ref $options{exports} ne 'ARRAY';
             @exports = @{$options{exports}};
-            croak $too_complicated if first { ref } @exports;
+            _croak $too_complicated if grep { length ref $_ } @exports;
 
          } elsif ($opt eq 'groups') {
             %tags = %{$options{groups}};
             for my $tagset (values %tags) {
-               croak $too_complicated if first { / \A - (?! all \b ) /x || ref } @{$tagset};
+               _croak $too_complicated if grep {
+                  length ref $_
+                     or
+                  $_ =~ / \A - (?! all \b ) /x
+               } @{$tagset};
             }
             @defaults = @{$tags{default} || [] };
          } else {
-            croak $too_complicated;
+            _croak $too_complicated;
          }
       }
       @{$_} = map { / \A  [:-] all \z /x ? @exports : $_ } @{$_} for \@defaults, values %tags;
       $tags{all} ||= [ @exports ];
       my %exports = map { $_ => 1 } @exports;
       my @errors = grep { not $exports{$_} } @defaults;
-      croak join(', ', @errors) . " is not exported by the $inner_target module\n" if @errors;
+      _croak join(', ', @errors) . " is not exported by the $inner_target module\n" if @errors;
    }
 
    return {
@@ -90,12 +102,20 @@ sub sub_export_options {
 
 1;
 
-=encoding utf8
+__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Sub::Exporter::Progressive - Only use Sub::Exporter if you need it
 
+=head1 VERSION
+
+version 0.001012
+
 =head1 SYNOPSIS
 
  package Syntax::Keyword::Gather;
@@ -103,7 +123,7 @@ Sub::Exporter::Progressive - Only use Sub::Exporter if you need it
  use Sub::Exporter::Progressive -setup => {
    exports => [qw( break gather gathered take )],
    groups => {
-     defaults => [qw( break gather gathered take )],
+     default => [qw( break gather gathered take )],
    },
  };
 
@@ -123,7 +143,7 @@ L<Sub::Exporter> is an incredibly powerful module, but with that power comes
 great responsibility, er- as well as some runtime penalties.  This module
 is a C<Sub::Exporter> wrapper that will let your users just use L<Exporter>
 if all they are doing is picking exports, but use C<Sub::Exporter> if your
-users try to use C<Sub::Exporter>'s more advanced features features, like
+users try to use C<Sub::Exporter>'s more advanced features, like
 renaming exports, if they try to use them.
 
 Note that this module will export C<@EXPORT>, C<@EXPORT_OK> and
@@ -131,10 +151,6 @@ C<%EXPORT_TAGS> package variables for C<Exporter> to work.  Additionally, if
 your package uses advanced C<Sub::Exporter> features like currying, this module
 will only ever use C<Sub::Exporter>, so you might as well use it directly.
 
-=head1 AUTHOR
-
-frew - Arthur Axel Schmidt (cpan:FREW) <frioux+cpan@gmail.com>
-
 =head1 CONTRIBUTORS
 
 ilmari - Dagfinn Ilmari Mannsåker (cpan:ILMARI) <ilmari@ilmari.org>
@@ -143,14 +159,15 @@ mst - Matt S. Trout (cpan:MSTROUT) <mst@shadowcat.co.uk>
 
 leont - Leon Timmermans (cpan:LEONT) <leont@cpan.org>
 
-=head1 COPYRIGHT
+=head1 AUTHOR
 
-Copyright (c) 2012 the Sub::Exporter::Progressive L</AUTHOR> and
-L</CONTRIBUTORS> as listed above.
+Arthur Axel "fREW" Schmidt <Sub-Exporter-Progressive@afoolishmanifesto.com>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This library is free software and may be distributed under the same terms
-as perl itself.
+This software is copyright (c) 2016 by Arthur Axel "fREW" Schmidt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
